@@ -115,7 +115,20 @@ void transform(sipSpec *pt)
 
     while (cd != NULL)
     {
-        classDef *next = cd -> next;
+        classDef *next;
+
+        /*
+         * Take the opportunity to strip any classes that are only template
+         * arguments.
+         */
+        while (isTemplateArg(cd))
+            if ((cd = cd->next) == NULL)
+                break;
+
+        if (cd == NULL)
+            break;
+
+        next = cd -> next;
 
         cd -> next = rev;
         rev = cd;
@@ -783,7 +796,8 @@ static void moveGlobalSlot(sipSpec *pt, moduleDef *mod, memberDef *gmd)
 
         if (mdhead == NULL)
         {
-            fatal("One of the arguments of ");
+            fatal("%s:%d: One of the arguments of ", od->sloc.name,
+                    od->sloc.linenr);
             prOverloadName(stderr, od);
             fatal(" must be a class or enum\n");
         }
@@ -798,14 +812,16 @@ static void moveGlobalSlot(sipSpec *pt, moduleDef *mod, memberDef *gmd)
         {
             if (second)
             {
-                fatal("The first argument of ");
+                fatal("%s:%d: The first argument of ", od->sloc.name,
+                        od->sloc.linenr);
                 prOverloadName(stderr, od);
                 fatal(" must be a class or enum\n");
             }
 
             if (mod != gmd->module && arg0->atype == enum_type)
             {
-                fatal("The first argument of ");
+                fatal("%s:%d: The first argument of ", od->sloc.name,
+                        od->sloc.linenr);
                 prOverloadName(stderr, od);
                 fatal(" must be a class\n");
             }
@@ -894,8 +910,11 @@ static void moveGlobalSlot(sipSpec *pt, moduleDef *mod, memberDef *gmd)
 
         *odhead = od;
 
-        /* Remove the first argument of comparison operators. */
-        if (isRichCompareSlot(md))
+        /*
+         * Remove the first argument of inplace numeric operators and
+         * comparison operators.
+         */
+        if (isInplaceNumberSlot(md) || isRichCompareSlot(md))
         {
             /* Remember if the argument was a pointer. */
             if (arg0->nrderefs > 0)
@@ -1349,7 +1368,8 @@ static void transformTypedefs(sipSpec *pt, moduleDef *mod)
 
     for (td = pt->typedefs; td != NULL; td = td->next)
         if (td->module == mod)
-            getBaseType(pt, td->module, td->ecd, &td->type);
+            if (td->ecd == NULL || !isTemplateClass(td->ecd))
+                getBaseType(pt, td->module, td->ecd, &td->type);
 }
 
 
@@ -1565,6 +1585,8 @@ static void transformScopeOverloads(sipSpec *pt, classDef *c_scope,
                 {
                     ifaceFileDef *iff;
 
+                    fatal("%s:%d: ", od->sloc.name, od->sloc.linenr);
+
                     if (mt_scope != NULL)
                         iff = mt_scope->iff;
                     else if (c_scope != NULL)
@@ -1887,7 +1909,7 @@ static void resolveFuncTypes(sipSpec *pt, moduleDef *mod, classDef *c_scope,
     {
         int a;
 
-        getBaseType(pt,mod, c_scope, &od->cppsig->result);
+        getBaseType(pt, mod, c_scope, &od->cppsig->result);
 
         for (a = 0; a < od->cppsig->nrArgs; ++a)
             getBaseType(pt, mod, c_scope, &od->cppsig->args[a]);
@@ -1902,26 +1924,29 @@ static void resolveFuncTypes(sipSpec *pt, moduleDef *mod, classDef *c_scope,
     if (isSSizeReturnSlot(od->common))
         if ((res->atype != ssize_type && res->atype != int_type) || res->nrderefs != 0 ||
             isReference(res) || isConstArg(res))
-            fatal("%s slots must return SIP_SSIZE_T\n",
-                    od->common->pyname->text);
+            fatal("%s:%d: %s slots must return SIP_SSIZE_T\n", od->sloc.name,
+                    od->sloc.linenr, od->common->pyname->text);
 
     /* These slots must return int. */
     if (isIntReturnSlot(od->common))
         if (res->atype != int_type || res->nrderefs != 0 ||
             isReference(res) || isConstArg(res))
-            fatal("%s slots must return int\n", od->common->pyname->text);
+            fatal("%s:%d: %s slots must return int\n", od->sloc.name,
+                    od->sloc.linenr, od->common->pyname->text);
 
     /* These slots must return void. */
     if (isVoidReturnSlot(od->common))
         if (res->atype != void_type || res->nrderefs != 0 ||
             isReference(res) || isConstArg(res))
-            fatal("%s slots must return void\n", od->common->pyname->text);
+            fatal("%s:%d: %s slots must return void\n", od->sloc.name,
+                    od->sloc.linenr, od->common->pyname->text);
 
     /* These slots must return long. */
     if (isLongReturnSlot(od->common))
         if (res->atype != long_type || res->nrderefs != 0 ||
             isReference(res) || isConstArg(res))
-            fatal("%s slots must return long\n", od->common->pyname->text);
+            fatal("%s:%d: %s slots must return long\n", od->sloc.name,
+                    od->sloc.linenr, od->common->pyname->text);
 }
 
 
@@ -1938,13 +1963,15 @@ static void resolvePySigTypes(sipSpec *pt, moduleDef *mod, classDef *scope,
     {
         if (issignal)
         {
+            fatal("%s:%d: ", od->sloc.name, od->sloc.linenr);
+
             if (scope != NULL)
             {
                 fatalScopedName(classFQCName(scope));
                 fatal("::");
             }
 
-            fatal("%s() signals must return void\n",od -> cppname);
+            fatal("%s() signals must return void\n", od->cppname);
         }
 
         getBaseType(pt, mod, scope, res);
@@ -1952,13 +1979,15 @@ static void resolvePySigTypes(sipSpec *pt, moduleDef *mod, classDef *scope,
         /* Results must be simple. */
         if (!supportedType(scope,od,res,FALSE) && (od -> cppsig == &od -> pysig || od -> methodcode == NULL))
         {
+            fatal("%s:%d: ", od->sloc.name, od->sloc.linenr);
+
             if (scope != NULL)
             {
                 fatalScopedName(classFQCName(scope));
                 fatal("::");
             }
 
-            fatal("%s() unsupported function return type - provide %%MethodCode and a %s signature\n",od -> cppname,(pt -> genc ? "C" : "C++"));
+            fatal("%s() unsupported function return type - provide %%MethodCode and a %s signature\n", od->cppname, (pt->genc ? "C" : "C++"));
         }
     }
 
@@ -1979,6 +2008,8 @@ static void resolvePySigTypes(sipSpec *pt, moduleDef *mod, classDef *scope,
         {
             if (!supportedType(scope,od,ad,FALSE))
             {
+                fatal("%s:%d: ", od->sloc.name, od->sloc.linenr);
+
                 if (scope != NULL)
                 {
                     fatalScopedName(classFQCName(scope));
@@ -1990,6 +2021,8 @@ static void resolvePySigTypes(sipSpec *pt, moduleDef *mod, classDef *scope,
         }
         else if (!supportedType(scope,od,ad,TRUE) && (od -> cppsig == &od -> pysig || od -> methodcode == NULL || (isVirtual(od) && od -> virthandler -> virtcode == NULL)))
         {
+            fatal("%s:%d: ", od->sloc.name, od->sloc.linenr);
+
             if (scope != NULL)
             {
                 fatalScopedName(classFQCName(scope));
@@ -1997,9 +2030,9 @@ static void resolvePySigTypes(sipSpec *pt, moduleDef *mod, classDef *scope,
             }
 
             if (isVirtual(od))
-                fatal("%s() unsupported function argument type - provide %%MethodCode, a valid %%VirtualCatcherCode and a valid C++ signature\n",od -> cppname);
+                fatal("%s() unsupported function argument type - provide %%MethodCode, a valid %%VirtualCatcherCode and a valid C++ signature\n", od->cppname);
 
-            fatal("%s() unsupported function argument type - provide %%MethodCode and a valid %s signature\n",od -> cppname,(pt -> genc ? "C" : "C++"));
+            fatal("%s() unsupported function argument type - provide %%MethodCode and a valid %s signature\n", od->cppname, (pt->genc ? "C" : "C++"));
         }
 
         if (scope != NULL)
@@ -2617,9 +2650,17 @@ int sameBaseType(argDef *a1, argDef *a2)
                 return FALSE;
 
             for (a = 0; a < td1->types.nrArgs; ++a)
-                if (!sameBaseType(&td1->types.args[a], &td2->types.args[a]))
+            {
+                argDef *td1ad = &td1->types.args[a];
+                argDef *td2ad = &td2->types.args[a];
+
+                if (td1ad->nrderefs != td2ad->nrderefs)
                     return FALSE;
 
+                if (!sameBaseType(td1ad, td2ad))
+                    return FALSE;
+            }
+
             break;
         }
 
@@ -2966,9 +3007,14 @@ static mappedTypeDef *instantiateMappedTypeTemplate(sipSpec *pt, moduleDef *mod,
 
     mtd->doctype = templateString(mtt->mt->doctype, type_names, type_values);
 
-    appendCodeBlock(&mtd->iff->hdrcode, templateCode(pt, &mtd->iff->used, mtt->mt->iff->hdrcode, type_names, type_values));
-    mtd->convfromcode = templateCode(pt, &mtd->iff->used, mtt->mt->convfromcode, type_names, type_values);
-    mtd->convtocode = templateCode(pt, &mtd->iff->used, mtt->mt->convtocode, type_names, type_values);
+    appendCodeBlockList(&mtd->iff->hdrcode,
+            templateCode(pt, &mtd->iff->used, mtt->mt->iff->hdrcode,
+                    type_names, type_values));
+
+    mtd->convfromcode = templateCode(pt, &mtd->iff->used,
+            mtt->mt->convfromcode, type_names, type_values);
+    mtd->convtocode = templateCode(pt, &mtd->iff->used, mtt->mt->convtocode,
+            type_names, type_values);
 
     mtd->next = pt->mappedtypes;
     pt->mappedtypes = mtd;
